@@ -5,7 +5,6 @@ from sbdscommons.constants import PARAMS_FOLDER
 from sbdscommons.utils.yaml_utils import load_from_yaml
 from sbdscommons.constants import MODEL_INPUT_DATA_TEMPLATE_QUERY
 from sbdscommons.constants import PREDICT_INPUT_DATA_TEMPLATE_QUERY
-from sbcommons.aws.redshift import RedshiftClient
 
 from .base import Model
 from .base import PrepInput
@@ -53,10 +52,11 @@ class SbModel:
         transformed_input = self.input_prep.transform(predict_input)
         return self.model.predict(transformed_input)
 
-    def get_query_from_template(self, template_path, params):
+    def get_query_from_template(self, template_path, params) -> str:
         with open(template_path, 'rt') as fr:
             query_template = fr.read()
-        return query_template.format(**params)
+        query_template_with_loaded_params = query_template.format(**params)
+        return query_template_with_loaded_params.replace("'", "''")
 
     def input_data_list(self):
         model_input_data_query = MODEL_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name)
